# Log in to AWS using ADFS

The aim for this is to create a general purpose CLI ADFS login with a limited set of trusted dependencies.

[![Codeship Status for NitorCreations/adfs-aws-login](https://app.codeship.com/projects//status?branch=master)](https://app.codeship.com/projects/)

## Installation

It's [available on PyPI](https://pypi.org/project/adfs-aws-login/). Install by running `pip install adfs-aws-login`.

## Run

The executable is called `adfs-aws-login`. Log in with default profile by simply running `adfs-aws-login` or specify a profile with `adfs-aws-login --profile [profile]`. 

See `adfs-aws-login -h` for more options.
